/* Screensaver.c generated by valac 0.56.19, the Vala compiler
 * generated from Screensaver.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_SCREENSAVER (screensaver_get_type ())
#define SCREENSAVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SCREENSAVER, Screensaver))
#define SCREENSAVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SCREENSAVER, ScreensaverClass))
#define IS_SCREENSAVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SCREENSAVER))
#define IS_SCREENSAVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SCREENSAVER))
#define SCREENSAVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SCREENSAVER, ScreensaverClass))

typedef struct _Screensaver Screensaver;
typedef struct _ScreensaverClass ScreensaverClass;
typedef struct _ScreensaverPrivate ScreensaverPrivate;

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
typedef struct _ParamSpecScreensaver ParamSpecScreensaver;

struct _Screensaver {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ScreensaverPrivate * priv;
};

struct _ScreensaverClass {
	GTypeClass parent_class;
	void (*finalize) (Screensaver *self);
};

struct _ScreensaverPrivate {
	guint32 cookie;
};

struct _ParamSpecScreensaver {
	GParamSpec parent_instance;
};

static gint Screensaver_private_offset;
static gpointer screensaver_parent_class = NULL;

VALA_EXTERN gpointer screensaver_ref (gpointer instance);
VALA_EXTERN void screensaver_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_screensaver (const gchar* name,
                                    const gchar* nick,
                                    const gchar* blurb,
                                    GType object_type,
                                    GParamFlags flags);
VALA_EXTERN void value_set_screensaver (GValue* value,
                            gpointer v_object);
VALA_EXTERN void value_take_screensaver (GValue* value,
                             gpointer v_object);
VALA_EXTERN gpointer value_get_screensaver (const GValue* value);
VALA_EXTERN GType screensaver_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Screensaver, screensaver_unref)
VALA_EXTERN Screensaver* screensaver_new (void);
VALA_EXTERN Screensaver* screensaver_construct (GType object_type);
VALA_EXTERN void screensaver_inhibit (Screensaver* self,
                          const gchar* reason);
VALA_EXTERN gpointer application_ref (gpointer instance);
VALA_EXTERN void application_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_application (const gchar* name,
                                    const gchar* nick,
                                    const gchar* blurb,
                                    GType object_type,
                                    GParamFlags flags);
VALA_EXTERN void value_set_application (GValue* value,
                            gpointer v_object);
VALA_EXTERN void value_take_application (GValue* value,
                             gpointer v_object);
VALA_EXTERN gpointer value_get_application (const GValue* value);
VALA_EXTERN GType application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Application, application_unref)
VALA_EXTERN Application* application_get_instance (void);
VALA_EXTERN guint application_inhibit (Application* self,
                           GtkApplicationInhibitFlags what,
                           const gchar* reason);
VALA_EXTERN void screensaver_uninhibit (Screensaver* self);
VALA_EXTERN void application_uninhibit (Application* self,
                            guint cookie);
static void screensaver_finalize (Screensaver * obj);
static GType screensaver_get_type_once (void);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
screensaver_get_instance_private (Screensaver* self)
{
	return G_STRUCT_MEMBER_P (self, Screensaver_private_offset);
}

Screensaver*
screensaver_construct (GType object_type)
{
	Screensaver* self = NULL;
	self = (Screensaver*) g_type_create_instance (object_type);
	return self;
}

Screensaver*
screensaver_new (void)
{
	return screensaver_construct (TYPE_SCREENSAVER);
}

void
screensaver_inhibit (Screensaver* self,
                     const gchar* reason)
{
	Application* _tmp0_;
	Application* _tmp1_;
	g_return_if_fail (IS_SCREENSAVER (self));
	g_return_if_fail (reason != NULL);
	if (self->priv->cookie != ((guint32) 0)) {
		return;
	}
	_tmp0_ = application_get_instance ();
	_tmp1_ = _tmp0_;
	self->priv->cookie = (guint32) application_inhibit (_tmp1_, GTK_APPLICATION_INHIBIT_IDLE | GTK_APPLICATION_INHIBIT_SUSPEND, _ ("Slideshow"));
	_application_unref0 (_tmp1_);
}

void
screensaver_uninhibit (Screensaver* self)
{
	Application* _tmp0_;
	Application* _tmp1_;
	g_return_if_fail (IS_SCREENSAVER (self));
	if (self->priv->cookie == ((guint32) 0)) {
		return;
	}
	_tmp0_ = application_get_instance ();
	_tmp1_ = _tmp0_;
	application_uninhibit (_tmp1_, (guint) self->priv->cookie);
	_application_unref0 (_tmp1_);
	self->priv->cookie = (guint32) 0;
}

static void
value_screensaver_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
value_screensaver_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		screensaver_unref (value->data[0].v_pointer);
	}
}

static void
value_screensaver_copy_value (const GValue* src_value,
                              GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = screensaver_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
value_screensaver_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
value_screensaver_collect_value (GValue* value,
                                 guint n_collect_values,
                                 GTypeCValue* collect_values,
                                 guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		Screensaver * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = screensaver_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
value_screensaver_lcopy_value (const GValue* value,
                               guint n_collect_values,
                               GTypeCValue* collect_values,
                               guint collect_flags)
{
	Screensaver ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = screensaver_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
param_spec_screensaver (const gchar* name,
                        const gchar* nick,
                        const gchar* blurb,
                        GType object_type,
                        GParamFlags flags)
{
	ParamSpecScreensaver* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_SCREENSAVER), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
value_get_screensaver (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SCREENSAVER), NULL);
	return value->data[0].v_pointer;
}

void
value_set_screensaver (GValue* value,
                       gpointer v_object)
{
	Screensaver * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SCREENSAVER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_SCREENSAVER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		screensaver_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		screensaver_unref (old);
	}
}

void
value_take_screensaver (GValue* value,
                        gpointer v_object)
{
	Screensaver * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SCREENSAVER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_SCREENSAVER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		screensaver_unref (old);
	}
}

static void
screensaver_class_init (ScreensaverClass * klass,
                        gpointer klass_data)
{
	screensaver_parent_class = g_type_class_peek_parent (klass);
	((ScreensaverClass *) klass)->finalize = screensaver_finalize;
	g_type_class_adjust_private_offset (klass, &Screensaver_private_offset);
}

static void
screensaver_instance_init (Screensaver * self,
                           gpointer klass)
{
	self->priv = screensaver_get_instance_private (self);
	self->priv->cookie = (guint32) 0;
	self->ref_count = 1;
}

static void
screensaver_finalize (Screensaver * obj)
{
	Screensaver * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SCREENSAVER, Screensaver);
	g_signal_handlers_destroy (self);
}

static GType
screensaver_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { value_screensaver_init, value_screensaver_free_value, value_screensaver_copy_value, value_screensaver_peek_pointer, "p", value_screensaver_collect_value, "p", value_screensaver_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (ScreensaverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) screensaver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Screensaver), 0, (GInstanceInitFunc) screensaver_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType screensaver_type_id;
	screensaver_type_id = g_type_register_fundamental (g_type_fundamental_next (), "Screensaver", &g_define_type_info, &g_define_type_fundamental_info, 0);
	Screensaver_private_offset = g_type_add_instance_private (screensaver_type_id, sizeof (ScreensaverPrivate));
	return screensaver_type_id;
}

GType
screensaver_get_type (void)
{
	static volatile gsize screensaver_type_id__once = 0;
	if (g_once_init_enter (&screensaver_type_id__once)) {
		GType screensaver_type_id;
		screensaver_type_id = screensaver_get_type_once ();
		g_once_init_leave (&screensaver_type_id__once, screensaver_type_id);
	}
	return screensaver_type_id__once;
}

gpointer
screensaver_ref (gpointer instance)
{
	Screensaver * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
screensaver_unref (gpointer instance)
{
	Screensaver * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		SCREENSAVER_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

