/* BuilderPane.c generated by valac 0.56.19, the Vala compiler
 * generated from BuilderPane.vala, do not modify */

/* Copyright 2016 Jens Georg <mail@jensge.org>
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include "shotwell-plugin-common.h"
#include "shotwell-plugin-dev-1.0.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_0_PROPERTY,
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_PREFERRED_GEOMETRY_PROPERTY,
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_RESOURCE_PATH_PROPERTY,
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CONNECT_SIGNALS_PROPERTY,
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_DEFAULT_ID_PROPERTY,
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_NUM_PROPERTIES
};
static GParamSpec* shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _ShotwellPluginsCommonBuilderPanePrivate {
	SpitPublishingDialogPaneGeometryOptions _preferred_geometry;
	gchar* _resource_path;
	gboolean _connect_signals;
	gchar* _default_id;
	GtkBuilder* builder;
	GtkWidget* content;
};

static gint ShotwellPluginsCommonBuilderPane_private_offset;
static gpointer shotwell_plugins_common_builder_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface * shotwell_plugins_common_builder_pane_spit_publishing_dialog_pane_parent_iface = NULL;

static void shotwell_plugins_common_builder_pane_real_constructed (GObject* base);
static SpitPublishingDialogPaneGeometryOptions shotwell_plugins_common_builder_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static GtkWidget* shotwell_plugins_common_builder_pane_real_get_widget (SpitPublishingDialogPane* base);
static GtkWidget* shotwell_plugins_common_builder_pane_real_get_default_widget (ShotwellPluginsCommonBuilderPane* self);
static void shotwell_plugins_common_builder_pane_real_on_pane_installed (ShotwellPluginsCommonBuilderPane* self);
static void shotwell_plugins_common_builder_pane_real_on_pane_uninstalled (ShotwellPluginsCommonBuilderPane* self);
static void shotwell_plugins_common_builder_pane_finalize (GObject * obj);
static GType shotwell_plugins_common_builder_pane_get_type_once (void);
static void _vala_shotwell_plugins_common_builder_pane_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_shotwell_plugins_common_builder_pane_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);

static inline gpointer
shotwell_plugins_common_builder_pane_get_instance_private (ShotwellPluginsCommonBuilderPane* self)
{
	return G_STRUCT_MEMBER_P (self, ShotwellPluginsCommonBuilderPane_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
shotwell_plugins_common_builder_pane_real_constructed (GObject* base)
{
	ShotwellPluginsCommonBuilderPane * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GtkBuilder* _tmp6_;
	gboolean _tmp7_;
	GtkBuilder* _tmp9_;
	GObject* _tmp10_;
	GtkWidget* _tmp11_;
	GtkWidget* _tmp12_;
	GtkContainer* _tmp13_;
	GtkContainer* _tmp14_;
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane);
	G_OBJECT_CLASS (shotwell_plugins_common_builder_pane_parent_class)->constructed (G_TYPE_CHECK_INSTANCE_CAST (self, G_TYPE_OBJECT, GObject));
	_tmp0_ = shotwell_plugins_common_builder_pane_get_resource_path (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	g_debug ("BuilderPane.vala:25: Adding new builder from path %s", _tmp2_);
	_g_free0 (_tmp2_);
	_tmp3_ = shotwell_plugins_common_builder_pane_get_resource_path (self);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = gtk_builder_new_from_resource (_tmp5_);
	_g_object_unref0 (self->priv->builder);
	self->priv->builder = _tmp6_;
	_g_free0 (_tmp5_);
	_tmp7_ = self->priv->_connect_signals;
	if (_tmp7_) {
		GtkBuilder* _tmp8_;
		_tmp8_ = self->priv->builder;
		gtk_builder_connect_signals (_tmp8_, NULL);
	}
	_tmp9_ = self->priv->builder;
	_tmp10_ = gtk_builder_get_object (_tmp9_, "content");
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, gtk_widget_get_type ()) ? ((GtkWidget*) _tmp10_) : NULL);
	_g_object_unref0 (self->priv->content);
	self->priv->content = _tmp11_;
	_tmp12_ = self->priv->content;
	_tmp13_ = gtk_widget_get_parent (_tmp12_);
	_tmp14_ = _tmp13_;
	if (_tmp14_ != NULL) {
		GtkWidget* _tmp15_;
		GtkContainer* _tmp16_;
		GtkContainer* _tmp17_;
		GtkWidget* _tmp18_;
		_tmp15_ = self->priv->content;
		_tmp16_ = gtk_widget_get_parent (_tmp15_);
		_tmp17_ = _tmp16_;
		_tmp18_ = self->priv->content;
		gtk_container_remove (_tmp17_, _tmp18_);
	}
}

static SpitPublishingDialogPaneGeometryOptions
shotwell_plugins_common_builder_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	ShotwellPluginsCommonBuilderPane * self;
	SpitPublishingDialogPaneGeometryOptions _tmp0_;
	SpitPublishingDialogPaneGeometryOptions result;
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane);
	_tmp0_ = self->priv->_preferred_geometry;
	result = _tmp0_;
	return result;
}

static GtkWidget*
shotwell_plugins_common_builder_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	ShotwellPluginsCommonBuilderPane * self;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* result;
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane);
	_tmp0_ = self->priv->content;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

GtkBuilder*
shotwell_plugins_common_builder_pane_get_builder (ShotwellPluginsCommonBuilderPane* self)
{
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp1_;
	GtkBuilder* result;
	g_return_val_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self), NULL);
	_tmp0_ = self->priv->builder;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

static GtkWidget*
shotwell_plugins_common_builder_pane_real_get_default_widget (ShotwellPluginsCommonBuilderPane* self)
{
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GObject* _tmp5_;
	GtkWidget* _tmp6_;
	GtkWidget* _tmp7_;
	GtkWidget* result;
	_tmp0_ = shotwell_plugins_common_builder_pane_get_builder (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = shotwell_plugins_common_builder_pane_get_default_id (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = gtk_builder_get_object (_tmp1_, _tmp4_);
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_widget_get_type ()) ? ((GtkWidget*) _tmp5_) : NULL);
	_tmp7_ = _tmp6_;
	_g_free0 (_tmp4_);
	_g_object_unref0 (_tmp1_);
	result = _tmp7_;
	return result;
}

GtkWidget*
shotwell_plugins_common_builder_pane_get_default_widget (ShotwellPluginsCommonBuilderPane* self)
{
	ShotwellPluginsCommonBuilderPaneClass* _klass_;
	g_return_val_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self), NULL);
	_klass_ = SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_GET_CLASS (self);
	if (_klass_->get_default_widget) {
		return _klass_->get_default_widget (self);
	}
	return NULL;
}

static void
shotwell_plugins_common_builder_pane_real_on_pane_installed (ShotwellPluginsCommonBuilderPane* self)
{
}

void
shotwell_plugins_common_builder_pane_on_pane_installed (ShotwellPluginsCommonBuilderPane* self)
{
	ShotwellPluginsCommonBuilderPaneClass* _klass_;
	g_return_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self));
	_klass_ = SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_GET_CLASS (self);
	if (_klass_->on_pane_installed) {
		_klass_->on_pane_installed (self);
	}
}

static void
shotwell_plugins_common_builder_pane_real_on_pane_uninstalled (ShotwellPluginsCommonBuilderPane* self)
{
}

void
shotwell_plugins_common_builder_pane_on_pane_uninstalled (ShotwellPluginsCommonBuilderPane* self)
{
	ShotwellPluginsCommonBuilderPaneClass* _klass_;
	g_return_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self));
	_klass_ = SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_GET_CLASS (self);
	if (_klass_->on_pane_uninstalled) {
		_klass_->on_pane_uninstalled (self);
	}
}

ShotwellPluginsCommonBuilderPane*
shotwell_plugins_common_builder_pane_construct (GType object_type)
{
	ShotwellPluginsCommonBuilderPane * self = NULL;
	self = (ShotwellPluginsCommonBuilderPane*) g_object_new (object_type, NULL);
	return self;
}

SpitPublishingDialogPaneGeometryOptions
shotwell_plugins_common_builder_pane_get_preferred_geometry (ShotwellPluginsCommonBuilderPane* self)
{
	SpitPublishingDialogPaneGeometryOptions result;
	g_return_val_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self), 0);
	result = self->priv->_preferred_geometry;
	return result;
}

static void
shotwell_plugins_common_builder_pane_set_preferred_geometry (ShotwellPluginsCommonBuilderPane* self,
                                                             SpitPublishingDialogPaneGeometryOptions value)
{
	SpitPublishingDialogPaneGeometryOptions old_value;
	g_return_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self));
	old_value = shotwell_plugins_common_builder_pane_get_preferred_geometry (self);
	if (old_value != value) {
		self->priv->_preferred_geometry = value;
		g_object_notify_by_pspec ((GObject *) self, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_PREFERRED_GEOMETRY_PROPERTY]);
	}
}

gchar*
shotwell_plugins_common_builder_pane_get_resource_path (ShotwellPluginsCommonBuilderPane* self)
{
	gchar* result;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	g_return_val_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self), NULL);
	_tmp0_ = self->priv->_resource_path;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
shotwell_plugins_common_builder_pane_set_resource_path (ShotwellPluginsCommonBuilderPane* self,
                                                        const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self));
	old_value = shotwell_plugins_common_builder_pane_get_resource_path (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_resource_path);
		self->priv->_resource_path = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_RESOURCE_PATH_PROPERTY]);
	}
	_g_free0 (old_value);
}

gboolean
shotwell_plugins_common_builder_pane_get_connect_signals (ShotwellPluginsCommonBuilderPane* self)
{
	gboolean result;
	g_return_val_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self), FALSE);
	result = self->priv->_connect_signals;
	return result;
}

static void
shotwell_plugins_common_builder_pane_set_connect_signals (ShotwellPluginsCommonBuilderPane* self,
                                                          gboolean value)
{
	gboolean old_value;
	g_return_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self));
	old_value = shotwell_plugins_common_builder_pane_get_connect_signals (self);
	if (old_value != value) {
		self->priv->_connect_signals = value;
		g_object_notify_by_pspec ((GObject *) self, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CONNECT_SIGNALS_PROPERTY]);
	}
}

gchar*
shotwell_plugins_common_builder_pane_get_default_id (ShotwellPluginsCommonBuilderPane* self)
{
	gchar* result;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	g_return_val_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self), NULL);
	_tmp0_ = self->priv->_default_id;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
shotwell_plugins_common_builder_pane_set_default_id (ShotwellPluginsCommonBuilderPane* self,
                                                     const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (SHOTWELL_PLUGINS_COMMON_IS_BUILDER_PANE (self));
	old_value = shotwell_plugins_common_builder_pane_get_default_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_default_id);
		self->priv->_default_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_DEFAULT_ID_PROPERTY]);
	}
	_g_free0 (old_value);
}

static void
shotwell_plugins_common_builder_pane_class_init (ShotwellPluginsCommonBuilderPaneClass * klass,
                                                 gpointer klass_data)
{
	shotwell_plugins_common_builder_pane_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ShotwellPluginsCommonBuilderPane_private_offset);
	((GObjectClass *) klass)->constructed = (void (*) (GObject*)) shotwell_plugins_common_builder_pane_real_constructed;
	((ShotwellPluginsCommonBuilderPaneClass *) klass)->get_default_widget = (GtkWidget* (*) (ShotwellPluginsCommonBuilderPane*)) shotwell_plugins_common_builder_pane_real_get_default_widget;
	((ShotwellPluginsCommonBuilderPaneClass *) klass)->on_pane_installed = (void (*) (ShotwellPluginsCommonBuilderPane*)) shotwell_plugins_common_builder_pane_real_on_pane_installed;
	((ShotwellPluginsCommonBuilderPaneClass *) klass)->on_pane_uninstalled = (void (*) (ShotwellPluginsCommonBuilderPane*)) shotwell_plugins_common_builder_pane_real_on_pane_uninstalled;
	G_OBJECT_CLASS (klass)->get_property = _vala_shotwell_plugins_common_builder_pane_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_shotwell_plugins_common_builder_pane_set_property;
	G_OBJECT_CLASS (klass)->finalize = shotwell_plugins_common_builder_pane_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_PREFERRED_GEOMETRY_PROPERTY, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_PREFERRED_GEOMETRY_PROPERTY] = g_param_spec_enum ("preferred-geometry", "preferred-geometry", "preferred-geometry", SPIT_PUBLISHING_DIALOG_PANE_TYPE_GEOMETRY_OPTIONS, SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_RESOURCE_PATH_PROPERTY, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_RESOURCE_PATH_PROPERTY] = g_param_spec_string ("resource-path", "resource-path", "resource-path", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CONNECT_SIGNALS_PROPERTY, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CONNECT_SIGNALS_PROPERTY] = g_param_spec_boolean ("connect-signals", "connect-signals", "connect-signals", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_DEFAULT_ID_PROPERTY, shotwell_plugins_common_builder_pane_properties[SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_DEFAULT_ID_PROPERTY] = g_param_spec_string ("default-id", "default-id", "default-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}

static void
shotwell_plugins_common_builder_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface,
                                                                                 gpointer iface_data)
{
	shotwell_plugins_common_builder_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane*)) shotwell_plugins_common_builder_pane_real_get_preferred_geometry;
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane*)) shotwell_plugins_common_builder_pane_real_get_widget;
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane*)) shotwell_plugins_common_builder_pane_on_pane_installed;
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane*)) shotwell_plugins_common_builder_pane_on_pane_uninstalled;
}

static void
shotwell_plugins_common_builder_pane_instance_init (ShotwellPluginsCommonBuilderPane * self,
                                                    gpointer klass)
{
	gchar* _tmp0_;
	self->priv = shotwell_plugins_common_builder_pane_get_instance_private (self);
	self->priv->_preferred_geometry = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
	self->priv->_connect_signals = FALSE;
	_tmp0_ = g_strdup ("default");
	self->priv->_default_id = _tmp0_;
}

static void
shotwell_plugins_common_builder_pane_finalize (GObject * obj)
{
	ShotwellPluginsCommonBuilderPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane);
	_g_free0 (self->priv->_resource_path);
	_g_free0 (self->priv->_default_id);
	_g_object_unref0 (self->priv->builder);
	_g_object_unref0 (self->priv->content);
	G_OBJECT_CLASS (shotwell_plugins_common_builder_pane_parent_class)->finalize (obj);
}

static GType
shotwell_plugins_common_builder_pane_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ShotwellPluginsCommonBuilderPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_plugins_common_builder_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellPluginsCommonBuilderPane), 0, (GInstanceInitFunc) shotwell_plugins_common_builder_pane_instance_init, NULL };
	static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) shotwell_plugins_common_builder_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType shotwell_plugins_common_builder_pane_type_id;
	shotwell_plugins_common_builder_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellPluginsCommonBuilderPane", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	g_type_add_interface_static (shotwell_plugins_common_builder_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
	ShotwellPluginsCommonBuilderPane_private_offset = g_type_add_instance_private (shotwell_plugins_common_builder_pane_type_id, sizeof (ShotwellPluginsCommonBuilderPanePrivate));
	return shotwell_plugins_common_builder_pane_type_id;
}

GType
shotwell_plugins_common_builder_pane_get_type (void)
{
	static volatile gsize shotwell_plugins_common_builder_pane_type_id__once = 0;
	if (g_once_init_enter (&shotwell_plugins_common_builder_pane_type_id__once)) {
		GType shotwell_plugins_common_builder_pane_type_id;
		shotwell_plugins_common_builder_pane_type_id = shotwell_plugins_common_builder_pane_get_type_once ();
		g_once_init_leave (&shotwell_plugins_common_builder_pane_type_id__once, shotwell_plugins_common_builder_pane_type_id);
	}
	return shotwell_plugins_common_builder_pane_type_id__once;
}

static void
_vala_shotwell_plugins_common_builder_pane_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	ShotwellPluginsCommonBuilderPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane);
	switch (property_id) {
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_PREFERRED_GEOMETRY_PROPERTY:
		g_value_set_enum (value, shotwell_plugins_common_builder_pane_get_preferred_geometry (self));
		break;
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_RESOURCE_PATH_PROPERTY:
		g_value_take_string (value, shotwell_plugins_common_builder_pane_get_resource_path (self));
		break;
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CONNECT_SIGNALS_PROPERTY:
		g_value_set_boolean (value, shotwell_plugins_common_builder_pane_get_connect_signals (self));
		break;
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_DEFAULT_ID_PROPERTY:
		g_value_take_string (value, shotwell_plugins_common_builder_pane_get_default_id (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_shotwell_plugins_common_builder_pane_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	ShotwellPluginsCommonBuilderPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane);
	switch (property_id) {
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_PREFERRED_GEOMETRY_PROPERTY:
		shotwell_plugins_common_builder_pane_set_preferred_geometry (self, g_value_get_enum (value));
		break;
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_RESOURCE_PATH_PROPERTY:
		shotwell_plugins_common_builder_pane_set_resource_path (self, g_value_get_string (value));
		break;
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CONNECT_SIGNALS_PROPERTY:
		shotwell_plugins_common_builder_pane_set_connect_signals (self, g_value_get_boolean (value));
		break;
		case SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_DEFAULT_ID_PROPERTY:
		shotwell_plugins_common_builder_pane_set_default_id (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

