/* MediaMetadata.c generated by valac 0.56.19, the Vala compiler
 * generated from MediaMetadata.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include "metadata.h"
#include <gio/gio.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib-object.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

typedef struct _ParamSpecMediaMetadata ParamSpecMediaMetadata;

struct _ParamSpecMediaMetadata {
	GParamSpec parent_instance;
};

static gpointer media_metadata_parent_class = NULL;

static void media_metadata_real_read_from_file (MediaMetadata* self,
                                         GFile* file,
                                         GError** error);
static MetadataDateTime* media_metadata_real_get_creation_date_time (MediaMetadata* self);
static gchar* media_metadata_real_get_title (MediaMetadata* self);
static gchar* media_metadata_real_get_comment (MediaMetadata* self);
static void media_metadata_finalize (MediaMetadata * obj);
static GType media_metadata_get_type_once (void);

static void
media_metadata_real_read_from_file (MediaMetadata* self,
                                    GFile* file,
                                    GError** error)
{
	g_critical ("Type `%s' does not implement abstract method `media_metadata_read_from_file'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return;
}

void
media_metadata_read_from_file (MediaMetadata* self,
                               GFile* file,
                               GError** error)
{
	MediaMetadataClass* _klass_;
	g_return_if_fail (IS_MEDIA_METADATA (self));
	_klass_ = MEDIA_METADATA_GET_CLASS (self);
	if (_klass_->read_from_file) {
		_klass_->read_from_file (self, file, error);
	}
}

static MetadataDateTime*
media_metadata_real_get_creation_date_time (MediaMetadata* self)
{
	g_critical ("Type `%s' does not implement abstract method `media_metadata_get_creation_date_time'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

MetadataDateTime*
media_metadata_get_creation_date_time (MediaMetadata* self)
{
	MediaMetadataClass* _klass_;
	g_return_val_if_fail (IS_MEDIA_METADATA (self), NULL);
	_klass_ = MEDIA_METADATA_GET_CLASS (self);
	if (_klass_->get_creation_date_time) {
		return _klass_->get_creation_date_time (self);
	}
	return NULL;
}

static gchar*
media_metadata_real_get_title (MediaMetadata* self)
{
	g_critical ("Type `%s' does not implement abstract method `media_metadata_get_title'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gchar*
media_metadata_get_title (MediaMetadata* self)
{
	MediaMetadataClass* _klass_;
	g_return_val_if_fail (IS_MEDIA_METADATA (self), NULL);
	_klass_ = MEDIA_METADATA_GET_CLASS (self);
	if (_klass_->get_title) {
		return _klass_->get_title (self);
	}
	return NULL;
}

static gchar*
media_metadata_real_get_comment (MediaMetadata* self)
{
	g_critical ("Type `%s' does not implement abstract method `media_metadata_get_comment'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

gchar*
media_metadata_get_comment (MediaMetadata* self)
{
	MediaMetadataClass* _klass_;
	g_return_val_if_fail (IS_MEDIA_METADATA (self), NULL);
	_klass_ = MEDIA_METADATA_GET_CLASS (self);
	if (_klass_->get_comment) {
		return _klass_->get_comment (self);
	}
	return NULL;
}

MediaMetadata*
media_metadata_construct (GType object_type)
{
	MediaMetadata* self = NULL;
	self = (MediaMetadata*) g_type_create_instance (object_type);
	return self;
}

static void
value_media_metadata_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
value_media_metadata_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		media_metadata_unref (value->data[0].v_pointer);
	}
}

static void
value_media_metadata_copy_value (const GValue* src_value,
                                 GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = media_metadata_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
value_media_metadata_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
value_media_metadata_collect_value (GValue* value,
                                    guint n_collect_values,
                                    GTypeCValue* collect_values,
                                    guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		MediaMetadata * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = media_metadata_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
value_media_metadata_lcopy_value (const GValue* value,
                                  guint n_collect_values,
                                  GTypeCValue* collect_values,
                                  guint collect_flags)
{
	MediaMetadata ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = media_metadata_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
param_spec_media_metadata (const gchar* name,
                           const gchar* nick,
                           const gchar* blurb,
                           GType object_type,
                           GParamFlags flags)
{
	ParamSpecMediaMetadata* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_MEDIA_METADATA), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
value_get_media_metadata (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MEDIA_METADATA), NULL);
	return value->data[0].v_pointer;
}

void
value_set_media_metadata (GValue* value,
                          gpointer v_object)
{
	MediaMetadata * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MEDIA_METADATA));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MEDIA_METADATA));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		media_metadata_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		media_metadata_unref (old);
	}
}

void
value_take_media_metadata (GValue* value,
                           gpointer v_object)
{
	MediaMetadata * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MEDIA_METADATA));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MEDIA_METADATA));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		media_metadata_unref (old);
	}
}

static void
media_metadata_class_init (MediaMetadataClass * klass,
                           gpointer klass_data)
{
	media_metadata_parent_class = g_type_class_peek_parent (klass);
	((MediaMetadataClass *) klass)->finalize = media_metadata_finalize;
	((MediaMetadataClass *) klass)->read_from_file = (void (*) (MediaMetadata*, GFile*, GError**)) media_metadata_real_read_from_file;
	((MediaMetadataClass *) klass)->get_creation_date_time = (MetadataDateTime* (*) (MediaMetadata*)) media_metadata_real_get_creation_date_time;
	((MediaMetadataClass *) klass)->get_title = (gchar* (*) (MediaMetadata*)) media_metadata_real_get_title;
	((MediaMetadataClass *) klass)->get_comment = (gchar* (*) (MediaMetadata*)) media_metadata_real_get_comment;
}

static void
media_metadata_instance_init (MediaMetadata * self,
                              gpointer klass)
{
	self->ref_count = 1;
}

static void
media_metadata_finalize (MediaMetadata * obj)
{
	MediaMetadata * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MEDIA_METADATA, MediaMetadata);
	g_signal_handlers_destroy (self);
}

static GType
media_metadata_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { value_media_metadata_init, value_media_metadata_free_value, value_media_metadata_copy_value, value_media_metadata_peek_pointer, "p", value_media_metadata_collect_value, "p", value_media_metadata_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (MediaMetadataClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) media_metadata_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MediaMetadata), 0, (GInstanceInitFunc) media_metadata_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType media_metadata_type_id;
	media_metadata_type_id = g_type_register_fundamental (g_type_fundamental_next (), "MediaMetadata", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
	return media_metadata_type_id;
}

GType
media_metadata_get_type (void)
{
	static volatile gsize media_metadata_type_id__once = 0;
	if (g_once_init_enter (&media_metadata_type_id__once)) {
		GType media_metadata_type_id;
		media_metadata_type_id = media_metadata_get_type_once ();
		g_once_init_leave (&media_metadata_type_id__once, media_metadata_type_id);
	}
	return media_metadata_type_id__once;
}

gpointer
media_metadata_ref (gpointer instance)
{
	MediaMetadata * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
media_metadata_unref (gpointer instance)
{
	MediaMetadata * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		MEDIA_METADATA_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

