/* shotwell-publishing.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_SHOTWELL_PUBLISHING_SHOTWELL_PUBLISHING_H__
#define __PLUGINS_SHOTWELL_PUBLISHING_SHOTWELL_PUBLISHING_H__

#include "shotwell-plugin-dev-1.0.h"
#include <glib-object.h>
#include <glib.h>
#include "shotwell-plugin-common.h"
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_FLICKR_SERVICE (flickr_service_get_type ())
#define FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FLICKR_SERVICE, FlickrService))
#define FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FLICKR_SERVICE, FlickrServiceClass))
#define IS_FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FLICKR_SERVICE))
#define IS_FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FLICKR_SERVICE))
#define FLICKR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FLICKR_SERVICE, FlickrServiceClass))

typedef struct _FlickrService FlickrService;
typedef struct _FlickrServiceClass FlickrServiceClass;
typedef struct _FlickrServicePrivate FlickrServicePrivate;

#define PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER (publishing_flickr_flickr_publisher_get_type ())
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher))
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherClass))
#define PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER))
#define PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER))
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherClass))

typedef struct _PublishingFlickrFlickrPublisher PublishingFlickrFlickrPublisher;
typedef struct _PublishingFlickrFlickrPublisherClass PublishingFlickrFlickrPublisherClass;
typedef struct _PublishingFlickrFlickrPublisherPrivate PublishingFlickrFlickrPublisherPrivate;

#define TYPE_TUMBLR_SERVICE (tumblr_service_get_type ())
#define TUMBLR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TUMBLR_SERVICE, TumblrService))
#define TUMBLR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TUMBLR_SERVICE, TumblrServiceClass))
#define IS_TUMBLR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TUMBLR_SERVICE))
#define IS_TUMBLR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TUMBLR_SERVICE))
#define TUMBLR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TUMBLR_SERVICE, TumblrServiceClass))

typedef struct _TumblrService TumblrService;
typedef struct _TumblrServiceClass TumblrServiceClass;
typedef struct _TumblrServicePrivate TumblrServicePrivate;

#define PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER (publishing_tumblr_tumblr_publisher_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisherClass))
#define PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER))
#define PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisherClass))

typedef struct _PublishingTumblrTumblrPublisher PublishingTumblrTumblrPublisher;
typedef struct _PublishingTumblrTumblrPublisherClass PublishingTumblrTumblrPublisherClass;
typedef struct _PublishingTumblrTumblrPublisherPrivate PublishingTumblrTumblrPublisherPrivate;

#define TYPE_YOU_TUBE_SERVICE (you_tube_service_get_type ())
#define YOU_TUBE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_YOU_TUBE_SERVICE, YouTubeService))
#define YOU_TUBE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_YOU_TUBE_SERVICE, YouTubeServiceClass))
#define IS_YOU_TUBE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_YOU_TUBE_SERVICE))
#define IS_YOU_TUBE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_YOU_TUBE_SERVICE))
#define YOU_TUBE_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_YOU_TUBE_SERVICE, YouTubeServiceClass))

typedef struct _YouTubeService YouTubeService;
typedef struct _YouTubeServiceClass YouTubeServiceClass;
typedef struct _YouTubeServicePrivate YouTubeServicePrivate;

#define PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER (publishing_you_tube_you_tube_publisher_get_type ())
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisher))
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisherClass))
#define PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER))
#define PUBLISHING_YOU_TUBE_IS_YOU_TUBE_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER))
#define PUBLISHING_YOU_TUBE_YOU_TUBE_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_YOU_TUBE_TYPE_YOU_TUBE_PUBLISHER, PublishingYouTubeYouTubePublisherClass))

typedef struct _PublishingYouTubeYouTubePublisher PublishingYouTubeYouTubePublisher;
typedef struct _PublishingYouTubeYouTubePublisherClass PublishingYouTubeYouTubePublisherClass;
typedef struct _PublishingYouTubeYouTubePublisherPrivate PublishingYouTubeYouTubePublisherPrivate;

#define TYPE_PIWIGO_SERVICE (piwigo_service_get_type ())
#define PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PIWIGO_SERVICE, PiwigoService))
#define PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))
#define IS_PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PIWIGO_SERVICE))
#define IS_PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PIWIGO_SERVICE))
#define PIWIGO_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))

typedef struct _PiwigoService PiwigoService;
typedef struct _PiwigoServiceClass PiwigoServiceClass;
typedef struct _PiwigoServicePrivate PiwigoServicePrivate;

#define PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER (publishing_piwigo_piwigo_publisher_get_type ())
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher))
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherClass))
#define PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER))
#define PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER))
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherClass))

typedef struct _PublishingPiwigoPiwigoPublisher PublishingPiwigoPiwigoPublisher;
typedef struct _PublishingPiwigoPiwigoPublisherClass PublishingPiwigoPiwigoPublisherClass;
typedef struct _PublishingPiwigoPiwigoPublisherPrivate PublishingPiwigoPiwigoPublisherPrivate;

#define PUBLISHING_GOOGLE_PHOTOS_TYPE_PUBLISHER (publishing_google_photos_publisher_get_type ())
#define PUBLISHING_GOOGLE_PHOTOS_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GOOGLE_PHOTOS_TYPE_PUBLISHER, PublishingGooglePhotosPublisher))
#define PUBLISHING_GOOGLE_PHOTOS_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GOOGLE_PHOTOS_TYPE_PUBLISHER, PublishingGooglePhotosPublisherClass))
#define PUBLISHING_GOOGLE_PHOTOS_IS_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GOOGLE_PHOTOS_TYPE_PUBLISHER))
#define PUBLISHING_GOOGLE_PHOTOS_IS_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GOOGLE_PHOTOS_TYPE_PUBLISHER))
#define PUBLISHING_GOOGLE_PHOTOS_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GOOGLE_PHOTOS_TYPE_PUBLISHER, PublishingGooglePhotosPublisherClass))

typedef struct _PublishingGooglePhotosPublisher PublishingGooglePhotosPublisher;
typedef struct _PublishingGooglePhotosPublisherClass PublishingGooglePhotosPublisherClass;
typedef struct _PublishingGooglePhotosPublisherPrivate PublishingGooglePhotosPublisherPrivate;

#define PUBLISHING_GOOGLE_PHOTOS_TYPE_SERVICE (publishing_google_photos_service_get_type ())
#define PUBLISHING_GOOGLE_PHOTOS_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GOOGLE_PHOTOS_TYPE_SERVICE, PublishingGooglePhotosService))
#define PUBLISHING_GOOGLE_PHOTOS_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GOOGLE_PHOTOS_TYPE_SERVICE, PublishingGooglePhotosServiceClass))
#define PUBLISHING_GOOGLE_PHOTOS_IS_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GOOGLE_PHOTOS_TYPE_SERVICE))
#define PUBLISHING_GOOGLE_PHOTOS_IS_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GOOGLE_PHOTOS_TYPE_SERVICE))
#define PUBLISHING_GOOGLE_PHOTOS_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GOOGLE_PHOTOS_TYPE_SERVICE, PublishingGooglePhotosServiceClass))

typedef struct _PublishingGooglePhotosService PublishingGooglePhotosService;
typedef struct _PublishingGooglePhotosServiceClass PublishingGooglePhotosServiceClass;
typedef struct _PublishingGooglePhotosServicePrivate PublishingGooglePhotosServicePrivate;

struct _FlickrService {
	GObject parent_instance;
	FlickrServicePrivate * priv;
};

struct _FlickrServiceClass {
	GObjectClass parent_class;
};

struct _PublishingFlickrFlickrPublisher {
	GObject parent_instance;
	PublishingFlickrFlickrPublisherPrivate * priv;
};

struct _PublishingFlickrFlickrPublisherClass {
	GObjectClass parent_class;
};

struct _TumblrService {
	GObject parent_instance;
	TumblrServicePrivate * priv;
};

struct _TumblrServiceClass {
	GObjectClass parent_class;
};

struct _PublishingTumblrTumblrPublisher {
	GObject parent_instance;
	PublishingTumblrTumblrPublisherPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherClass {
	GObjectClass parent_class;
};

struct _YouTubeService {
	GObject parent_instance;
	YouTubeServicePrivate * priv;
};

struct _YouTubeServiceClass {
	GObjectClass parent_class;
};

struct _PublishingYouTubeYouTubePublisher {
	PublishingRESTSupportGooglePublisher parent_instance;
	PublishingYouTubeYouTubePublisherPrivate * priv;
};

struct _PublishingYouTubeYouTubePublisherClass {
	PublishingRESTSupportGooglePublisherClass parent_class;
};

struct _PiwigoService {
	GObject parent_instance;
	PiwigoServicePrivate * priv;
};

struct _PiwigoServiceClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoPiwigoPublisher {
	GObject parent_instance;
	PublishingPiwigoPiwigoPublisherPrivate * priv;
};

struct _PublishingPiwigoPiwigoPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingGooglePhotosPublisher {
	PublishingRESTSupportGooglePublisher parent_instance;
	PublishingGooglePhotosPublisherPrivate * priv;
};

struct _PublishingGooglePhotosPublisherClass {
	PublishingRESTSupportGooglePublisherClass parent_class;
};

struct _PublishingGooglePhotosService {
	GObject parent_instance;
	PublishingGooglePhotosServicePrivate * priv;
};

struct _PublishingGooglePhotosServiceClass {
	GObjectClass parent_class;
};

VALA_EXTERN SpitModule* spit_entry_point (SpitEntryPointParams* params);
VALA_EXTERN GType flickr_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FlickrService, g_object_unref)
VALA_EXTERN FlickrService* flickr_service_new (void);
VALA_EXTERN FlickrService* flickr_service_construct (GType object_type);
VALA_EXTERN GType publishing_flickr_flickr_publisher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingFlickrFlickrPublisher, g_object_unref)
VALA_EXTERN PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_new (SpitPublishingService* service,
                                                                         SpitPublishingPluginHost* host);
VALA_EXTERN PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_construct (GType object_type,
                                                                               SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
VALA_EXTERN SpitPublishingAuthenticator* publishing_flickr_flickr_publisher_get_authenticator (PublishingFlickrFlickrPublisher* self);
VALA_EXTERN gint publishing_flickr_flickr_publisher_flickr_date_time_compare_func (SpitPublishingPublishable* a,
                                                                       SpitPublishingPublishable* b);
VALA_EXTERN gchar* publishing_flickr_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
VALA_EXTERN PublishingRESTSupportXmlDocument* publishing_flickr_transaction_parse_flickr_response (const gchar* xml,
                                                                                       GError** error);
VALA_EXTERN GType tumblr_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TumblrService, g_object_unref)
VALA_EXTERN TumblrService* tumblr_service_new (void);
VALA_EXTERN TumblrService* tumblr_service_construct (GType object_type);
VALA_EXTERN GType publishing_tumblr_tumblr_publisher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingTumblrTumblrPublisher, g_object_unref)
VALA_EXTERN PublishingTumblrTumblrPublisher* publishing_tumblr_tumblr_publisher_new (SpitPublishingService* service,
                                                                         SpitPublishingPluginHost* host);
VALA_EXTERN PublishingTumblrTumblrPublisher* publishing_tumblr_tumblr_publisher_construct (GType object_type,
                                                                               SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
VALA_EXTERN SpitPublishingPluginHost* publishing_tumblr_tumblr_publisher_get_host (PublishingTumblrTumblrPublisher* self);
VALA_EXTERN gint publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func (SpitPublishingPublishable* a,
                                                                       SpitPublishingPublishable* b);
VALA_EXTERN void publishing_tumblr_tumblr_publisher_attempt_start (PublishingTumblrTumblrPublisher* self);
VALA_EXTERN GType you_tube_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (YouTubeService, g_object_unref)
VALA_EXTERN YouTubeService* you_tube_service_new (void);
VALA_EXTERN YouTubeService* you_tube_service_construct (GType object_type);
VALA_EXTERN GType publishing_you_tube_you_tube_publisher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingYouTubeYouTubePublisher, g_object_unref)
VALA_EXTERN PublishingYouTubeYouTubePublisher* publishing_you_tube_you_tube_publisher_new (SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
VALA_EXTERN PublishingYouTubeYouTubePublisher* publishing_you_tube_you_tube_publisher_construct (GType object_type,
                                                                                     SpitPublishingService* service,
                                                                                     SpitPublishingPluginHost* host);
VALA_EXTERN GType piwigo_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PiwigoService, g_object_unref)
VALA_EXTERN PiwigoService* piwigo_service_new (void);
VALA_EXTERN PiwigoService* piwigo_service_construct (GType object_type);
VALA_EXTERN GType publishing_piwigo_piwigo_publisher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingPiwigoPiwigoPublisher, g_object_unref)
VALA_EXTERN PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_new (SpitPublishingService* service,
                                                                         SpitPublishingPluginHost* host,
                                                                         SpitPublishingAccount* account);
VALA_EXTERN PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_construct (GType object_type,
                                                                               SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host,
                                                                               SpitPublishingAccount* account);
VALA_EXTERN SpitPublishingPluginHost* publishing_piwigo_piwigo_publisher_get_host (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gchar* publishing_piwigo_piwigo_publisher_get_persistent_url (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gchar* publishing_piwigo_piwigo_publisher_get_persistent_username (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gchar* publishing_piwigo_piwigo_publisher_get_persistent_password (PublishingPiwigoPiwigoPublisher* self,
                                                                   const gchar* url,
                                                                   const gchar* user);
VALA_EXTERN gboolean publishing_piwigo_piwigo_publisher_get_remember_password (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gint publishing_piwigo_piwigo_publisher_get_last_category (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gint publishing_piwigo_piwigo_publisher_get_last_permission_level (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gint publishing_piwigo_piwigo_publisher_get_last_photo_size (PublishingPiwigoPiwigoPublisher* self);
VALA_EXTERN gchar* publishing_piwigo_piwigo_publisher_normalise_url (const gchar* url);
VALA_EXTERN GType publishing_google_photos_publisher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingGooglePhotosPublisher, g_object_unref)
VALA_EXTERN PublishingGooglePhotosPublisher* publishing_google_photos_publisher_new (SpitPublishingService* service,
                                                                         SpitPublishingPluginHost* host);
VALA_EXTERN PublishingGooglePhotosPublisher* publishing_google_photos_publisher_construct (GType object_type,
                                                                               SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
VALA_EXTERN GType publishing_google_photos_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingGooglePhotosService, g_object_unref)
VALA_EXTERN PublishingGooglePhotosService* publishing_google_photos_service_new (void);
VALA_EXTERN PublishingGooglePhotosService* publishing_google_photos_service_construct (GType object_type);

G_END_DECLS

#endif
