/* PageMessagePane.c generated by valac 0.56.19, the Vala compiler
 * generated from PageMessagePane.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_PAGE_MESSAGE_PANE (page_message_pane_get_type ())
#define PAGE_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_MESSAGE_PANE, PageMessagePane))
#define PAGE_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_MESSAGE_PANE, PageMessagePaneClass))
#define IS_PAGE_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_MESSAGE_PANE))
#define IS_PAGE_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_MESSAGE_PANE))
#define PAGE_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_MESSAGE_PANE, PageMessagePaneClass))

typedef struct _PageMessagePane PageMessagePane;
typedef struct _PageMessagePaneClass PageMessagePaneClass;
typedef struct _PageMessagePanePrivate PageMessagePanePrivate;
enum  {
	PAGE_MESSAGE_PANE_0_PROPERTY,
	PAGE_MESSAGE_PANE_NUM_PROPERTIES
};
static GParamSpec* page_message_pane_properties[PAGE_MESSAGE_PANE_NUM_PROPERTIES];

struct _PageMessagePane {
	GtkBox parent_instance;
	PageMessagePanePrivate * priv;
	GtkLabel* label;
	GtkImage* icon_image;
};

struct _PageMessagePaneClass {
	GtkBoxClass parent_class;
};

static gpointer page_message_pane_parent_class = NULL;

VALA_EXTERN GType page_message_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PageMessagePane, g_object_unref)
VALA_EXTERN PageMessagePane* page_message_pane_new (void);
VALA_EXTERN PageMessagePane* page_message_pane_construct (GType object_type);
static void page_message_pane_finalize (GObject * obj);
static GType page_message_pane_get_type_once (void);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

PageMessagePane*
page_message_pane_construct (GType object_type)
{
	PageMessagePane * self = NULL;
	self = (PageMessagePane*) g_object_new (object_type, NULL);
	return self;
}

PageMessagePane*
page_message_pane_new (void)
{
	return page_message_pane_construct (TYPE_PAGE_MESSAGE_PANE);
}

static void
page_message_pane_class_init (PageMessagePaneClass * klass,
                              gpointer klass_data)
{
	page_message_pane_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = page_message_pane_finalize;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Shotwell/ui/message_pane.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "label", FALSE, G_STRUCT_OFFSET (PageMessagePane, label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "icon_image", FALSE, G_STRUCT_OFFSET (PageMessagePane, icon_image));
}

static void
page_message_pane_instance_init (PageMessagePane * self,
                                 gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
page_message_pane_finalize (GObject * obj)
{
	PageMessagePane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PAGE_MESSAGE_PANE, PageMessagePane);
	G_OBJECT_CLASS (page_message_pane_parent_class)->finalize (obj);
}

static GType
page_message_pane_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PageMessagePaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) page_message_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PageMessagePane), 0, (GInstanceInitFunc) page_message_pane_instance_init, NULL };
	GType page_message_pane_type_id;
	page_message_pane_type_id = g_type_register_static (gtk_box_get_type (), "PageMessagePane", &g_define_type_info, 0);
	return page_message_pane_type_id;
}

GType
page_message_pane_get_type (void)
{
	static volatile gsize page_message_pane_type_id__once = 0;
	if (g_once_init_enter (&page_message_pane_type_id__once)) {
		GType page_message_pane_type_id;
		page_message_pane_type_id = page_message_pane_get_type_once ();
		g_once_init_leave (&page_message_pane_type_id__once, page_message_pane_type_id);
	}
	return page_message_pane_type_id__once;
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

