/* shotwell-internal-publishing-gui.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __SRC_PUBLISHING_SHOTWELL_INTERNAL_PUBLISHING_GUI_H__
#define __SRC_PUBLISHING_SHOTWELL_INTERNAL_PUBLISHING_GUI_H__

#include <gtk/gtk.h>
#include "shotwell-plugin-dev-1.0.h"
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <float.h>
#include <math.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE (publishing_ui_static_message_pane_get_type ())
#define PUBLISHING_UI_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePane))
#define PUBLISHING_UI_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePaneClass))
#define PUBLISHING_UI_IS_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE))
#define PUBLISHING_UI_IS_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE))
#define PUBLISHING_UI_STATIC_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePaneClass))

typedef struct _PublishingUIStaticMessagePane PublishingUIStaticMessagePane;
typedef struct _PublishingUIStaticMessagePaneClass PublishingUIStaticMessagePaneClass;
typedef struct _PublishingUIStaticMessagePanePrivate PublishingUIStaticMessagePanePrivate;

#define PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE (publishing_ui_account_fetch_wait_pane_get_type ())
#define PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE, PublishingUIAccountFetchWaitPane))
#define PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE, PublishingUIAccountFetchWaitPaneClass))
#define PUBLISHING_UI_IS_ACCOUNT_FETCH_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE))
#define PUBLISHING_UI_IS_ACCOUNT_FETCH_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE))
#define PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE, PublishingUIAccountFetchWaitPaneClass))

typedef struct _PublishingUIAccountFetchWaitPane PublishingUIAccountFetchWaitPane;
typedef struct _PublishingUIAccountFetchWaitPaneClass PublishingUIAccountFetchWaitPaneClass;
typedef struct _PublishingUIAccountFetchWaitPanePrivate PublishingUIAccountFetchWaitPanePrivate;

#define PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE (publishing_ui_login_wait_pane_get_type ())
#define PUBLISHING_UI_LOGIN_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE, PublishingUILoginWaitPane))
#define PUBLISHING_UI_LOGIN_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE, PublishingUILoginWaitPaneClass))
#define PUBLISHING_UI_IS_LOGIN_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE))
#define PUBLISHING_UI_IS_LOGIN_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE))
#define PUBLISHING_UI_LOGIN_WAIT_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE, PublishingUILoginWaitPaneClass))

typedef struct _PublishingUILoginWaitPane PublishingUILoginWaitPane;
typedef struct _PublishingUILoginWaitPaneClass PublishingUILoginWaitPaneClass;
typedef struct _PublishingUILoginWaitPanePrivate PublishingUILoginWaitPanePrivate;

#define PUBLISHING_UI_TYPE_PROGRESS_PANE (publishing_ui_progress_pane_get_type ())
#define PUBLISHING_UI_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPane))
#define PUBLISHING_UI_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPaneClass))
#define PUBLISHING_UI_IS_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_PROGRESS_PANE))
#define PUBLISHING_UI_IS_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_PROGRESS_PANE))
#define PUBLISHING_UI_PROGRESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPaneClass))

typedef struct _PublishingUIProgressPane PublishingUIProgressPane;
typedef struct _PublishingUIProgressPaneClass PublishingUIProgressPaneClass;
typedef struct _PublishingUIProgressPanePrivate PublishingUIProgressPanePrivate;

#define PUBLISHING_UI_TYPE_SUCCESS_PANE (publishing_ui_success_pane_get_type ())
#define PUBLISHING_UI_SUCCESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_SUCCESS_PANE, PublishingUISuccessPane))
#define PUBLISHING_UI_SUCCESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_SUCCESS_PANE, PublishingUISuccessPaneClass))
#define PUBLISHING_UI_IS_SUCCESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_SUCCESS_PANE))
#define PUBLISHING_UI_IS_SUCCESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_SUCCESS_PANE))
#define PUBLISHING_UI_SUCCESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_SUCCESS_PANE, PublishingUISuccessPaneClass))

typedef struct _PublishingUISuccessPane PublishingUISuccessPane;
typedef struct _PublishingUISuccessPaneClass PublishingUISuccessPaneClass;
typedef struct _PublishingUISuccessPanePrivate PublishingUISuccessPanePrivate;

#define PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE (publishing_ui_login_welcome_pane_get_type ())
#define PUBLISHING_UI_LOGIN_WELCOME_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePane))
#define PUBLISHING_UI_LOGIN_WELCOME_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePaneClass))
#define PUBLISHING_UI_IS_LOGIN_WELCOME_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE))
#define PUBLISHING_UI_IS_LOGIN_WELCOME_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE))
#define PUBLISHING_UI_LOGIN_WELCOME_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePaneClass))

typedef struct _PublishingUILoginWelcomePane PublishingUILoginWelcomePane;
typedef struct _PublishingUILoginWelcomePaneClass PublishingUILoginWelcomePaneClass;
typedef struct _PublishingUILoginWelcomePanePrivate PublishingUILoginWelcomePanePrivate;

struct _PublishingUIStaticMessagePane {
	GtkBox parent_instance;
	PublishingUIStaticMessagePanePrivate * priv;
};

struct _PublishingUIStaticMessagePaneClass {
	GtkBoxClass parent_class;
};

struct _PublishingUIAccountFetchWaitPane {
	PublishingUIStaticMessagePane parent_instance;
	PublishingUIAccountFetchWaitPanePrivate * priv;
};

struct _PublishingUIAccountFetchWaitPaneClass {
	PublishingUIStaticMessagePaneClass parent_class;
};

struct _PublishingUILoginWaitPane {
	PublishingUIStaticMessagePane parent_instance;
	PublishingUILoginWaitPanePrivate * priv;
};

struct _PublishingUILoginWaitPaneClass {
	PublishingUIStaticMessagePaneClass parent_class;
};

struct _PublishingUIProgressPane {
	GtkBox parent_instance;
	PublishingUIProgressPanePrivate * priv;
};

struct _PublishingUIProgressPaneClass {
	GtkBoxClass parent_class;
};

struct _PublishingUISuccessPane {
	PublishingUIStaticMessagePane parent_instance;
	PublishingUISuccessPanePrivate * priv;
};

struct _PublishingUISuccessPaneClass {
	PublishingUIStaticMessagePaneClass parent_class;
};

struct _PublishingUILoginWelcomePane {
	GtkBox parent_instance;
	PublishingUILoginWelcomePanePrivate * priv;
};

struct _PublishingUILoginWelcomePaneClass {
	GtkBoxClass parent_class;
};

VALA_EXTERN GType publishing_ui_static_message_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingUIStaticMessagePane, g_object_unref)
VALA_EXTERN PublishingUIStaticMessagePane* publishing_ui_static_message_pane_new (const gchar* message_string,
                                                                      gboolean enable_markup,
                                                                      gboolean show_spinner);
VALA_EXTERN PublishingUIStaticMessagePane* publishing_ui_static_message_pane_construct (GType object_type,
                                                                            const gchar* message_string,
                                                                            gboolean enable_markup,
                                                                            gboolean show_spinner);
VALA_EXTERN gboolean publishing_ui_static_message_pane_get_show_spinner (PublishingUIStaticMessagePane* self);
VALA_EXTERN GType publishing_ui_account_fetch_wait_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingUIAccountFetchWaitPane, g_object_unref)
VALA_EXTERN PublishingUIAccountFetchWaitPane* publishing_ui_account_fetch_wait_pane_new (void);
VALA_EXTERN PublishingUIAccountFetchWaitPane* publishing_ui_account_fetch_wait_pane_construct (GType object_type);
VALA_EXTERN GType publishing_ui_login_wait_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingUILoginWaitPane, g_object_unref)
VALA_EXTERN PublishingUILoginWaitPane* publishing_ui_login_wait_pane_new (void);
VALA_EXTERN PublishingUILoginWaitPane* publishing_ui_login_wait_pane_construct (GType object_type);
VALA_EXTERN GType publishing_ui_progress_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingUIProgressPane, g_object_unref)
VALA_EXTERN void publishing_ui_progress_pane_set_text (PublishingUIProgressPane* self,
                                           const gchar* text);
VALA_EXTERN void publishing_ui_progress_pane_set_progress (PublishingUIProgressPane* self,
                                               gdouble progress);
VALA_EXTERN void publishing_ui_progress_pane_set_status (PublishingUIProgressPane* self,
                                             const gchar* status_text,
                                             gdouble progress);
VALA_EXTERN PublishingUIProgressPane* publishing_ui_progress_pane_new (void);
VALA_EXTERN PublishingUIProgressPane* publishing_ui_progress_pane_construct (GType object_type);
VALA_EXTERN GType publishing_ui_success_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingUISuccessPane, g_object_unref)
VALA_EXTERN PublishingUISuccessPane* publishing_ui_success_pane_new (SpitPublishingPublisherMediaType published_media,
                                                         gint num_uploaded);
VALA_EXTERN PublishingUISuccessPane* publishing_ui_success_pane_construct (GType object_type,
                                                               SpitPublishingPublisherMediaType published_media,
                                                               gint num_uploaded);
VALA_EXTERN GType publishing_ui_login_welcome_pane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PublishingUILoginWelcomePane, g_object_unref)
VALA_EXTERN PublishingUILoginWelcomePane* publishing_ui_login_welcome_pane_new (const gchar* service_welcome_message);
VALA_EXTERN PublishingUILoginWelcomePane* publishing_ui_login_welcome_pane_construct (GType object_type,
                                                                          const gchar* service_welcome_message);

G_END_DECLS

#endif
