/* ShotwellAuthenticatorFactory.c generated by valac 0.56.19, the Vala compiler
 * generated from ShotwellAuthenticatorFactory.vala, do not modify */

#include "shotwell-authenticator.h"
#include <glib.h>
#include <gee.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include "shotwell-plugin-dev-1.0.h"
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	PUBLISHING_AUTHENTICATOR_FACTORY_0_PROPERTY,
	PUBLISHING_AUTHENTICATOR_FACTORY_NUM_PROPERTIES
};
static GParamSpec* publishing_authenticator_factory_properties[PUBLISHING_AUTHENTICATOR_FACTORY_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_TYPE_AUTHENTICATOR (publishing_authenticator_shotwell_oauth1_authenticator_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_AUTHENTICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_TYPE_AUTHENTICATOR, PublishingAuthenticatorShotwellOAuth1Authenticator))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_AUTHENTICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_TYPE_AUTHENTICATOR, PublishingAuthenticatorShotwellOAuth1AuthenticatorClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_IS_AUTHENTICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_TYPE_AUTHENTICATOR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_IS_AUTHENTICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_TYPE_AUTHENTICATOR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_AUTHENTICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_OAUTH1_TYPE_AUTHENTICATOR, PublishingAuthenticatorShotwellOAuth1AuthenticatorClass))

typedef struct _PublishingAuthenticatorShotwellOAuth1Authenticator PublishingAuthenticatorShotwellOAuth1Authenticator;
typedef struct _PublishingAuthenticatorShotwellOAuth1AuthenticatorClass PublishingAuthenticatorShotwellOAuth1AuthenticatorClass;

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR (publishing_authenticator_shotwell_flickr_flickr_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_FLICKR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR, PublishingAuthenticatorShotwellFlickrFlickr))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_FLICKR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR, PublishingAuthenticatorShotwellFlickrFlickrClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_IS_FLICKR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_IS_FLICKR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_FLICKR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR, PublishingAuthenticatorShotwellFlickrFlickrClass))

typedef struct _PublishingAuthenticatorShotwellFlickrFlickr PublishingAuthenticatorShotwellFlickrFlickr;
typedef struct _PublishingAuthenticatorShotwellFlickrFlickrClass PublishingAuthenticatorShotwellFlickrFlickrClass;

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE (publishing_authenticator_shotwell_google_google_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_GOOGLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE, PublishingAuthenticatorShotwellGoogleGoogle))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_GOOGLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE, PublishingAuthenticatorShotwellGoogleGoogleClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_IS_GOOGLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_IS_GOOGLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_GOOGLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE, PublishingAuthenticatorShotwellGoogleGoogleClass))

typedef struct _PublishingAuthenticatorShotwellGoogleGoogle PublishingAuthenticatorShotwellGoogleGoogle;
typedef struct _PublishingAuthenticatorShotwellGoogleGoogleClass PublishingAuthenticatorShotwellGoogleGoogleClass;

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TYPE_TUMBLR (publishing_authenticator_shotwell_tumblr_tumblr_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TUMBLR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TYPE_TUMBLR, PublishingAuthenticatorShotwellTumblrTumblr))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TUMBLR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TYPE_TUMBLR, PublishingAuthenticatorShotwellTumblrTumblrClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_IS_TUMBLR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TYPE_TUMBLR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_IS_TUMBLR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TYPE_TUMBLR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TUMBLR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_TUMBLR_TYPE_TUMBLR, PublishingAuthenticatorShotwellTumblrTumblrClass))

typedef struct _PublishingAuthenticatorShotwellTumblrTumblr PublishingAuthenticatorShotwellTumblrTumblr;
typedef struct _PublishingAuthenticatorShotwellTumblrTumblrClass PublishingAuthenticatorShotwellTumblrTumblrClass;

static gpointer publishing_authenticator_factory_parent_class = NULL;
static PublishingAuthenticatorFactory* publishing_authenticator_factory_instance;
static PublishingAuthenticatorFactory* publishing_authenticator_factory_instance = NULL;
static SpitPublishingAuthenticatorFactoryIface * publishing_authenticator_factory_spit_publishing_authenticator_factory_parent_iface = NULL;

static GeeList* publishing_authenticator_factory_real_get_available_authenticators (SpitPublishingAuthenticatorFactory* base);
static SpitPublishingAuthenticator* publishing_authenticator_factory_real_create (SpitPublishingAuthenticatorFactory* base,
                                                                           const gchar* provider,
                                                                           SpitPublishingPluginHost* host);
VALA_EXTERN PublishingAuthenticatorShotwellFlickrFlickr* publishing_authenticator_shotwell_flickr_flickr_new (SpitPublishingPluginHost* host);
VALA_EXTERN PublishingAuthenticatorShotwellFlickrFlickr* publishing_authenticator_shotwell_flickr_flickr_construct (GType object_type,
                                                                                                        SpitPublishingPluginHost* host);
VALA_EXTERN GType publishing_authenticator_shotwell_oauth1_authenticator_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType publishing_authenticator_shotwell_flickr_flickr_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PublishingAuthenticatorShotwellGoogleGoogle* publishing_authenticator_shotwell_google_google_new (gchar** scopes,
                                                                                                  gint scopes_length1,
                                                                                                  const gchar* welcome_message,
                                                                                                  SpitPublishingPluginHost* host);
VALA_EXTERN PublishingAuthenticatorShotwellGoogleGoogle* publishing_authenticator_shotwell_google_google_construct (GType object_type,
                                                                                                        gchar** scopes,
                                                                                                        gint scopes_length1,
                                                                                                        const gchar* welcome_message,
                                                                                                        SpitPublishingPluginHost* host);
VALA_EXTERN GType publishing_authenticator_shotwell_google_google_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PublishingAuthenticatorShotwellTumblrTumblr* publishing_authenticator_shotwell_tumblr_tumblr_new (SpitPublishingPluginHost* host);
VALA_EXTERN PublishingAuthenticatorShotwellTumblrTumblr* publishing_authenticator_shotwell_tumblr_tumblr_construct (GType object_type,
                                                                                                        SpitPublishingPluginHost* host);
VALA_EXTERN GType publishing_authenticator_shotwell_tumblr_tumblr_get_type (void) G_GNUC_CONST ;
static void publishing_authenticator_factory_finalize (GObject * obj);
static GType publishing_authenticator_factory_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

PublishingAuthenticatorFactory*
publishing_authenticator_factory_get_instance (void)
{
	PublishingAuthenticatorFactory* _tmp0_;
	PublishingAuthenticatorFactory* _tmp2_;
	PublishingAuthenticatorFactory* _tmp3_;
	PublishingAuthenticatorFactory* result;
	_tmp0_ = publishing_authenticator_factory_instance;
	if (_tmp0_ == NULL) {
		PublishingAuthenticatorFactory* _tmp1_;
		_tmp1_ = publishing_authenticator_factory_new ();
		_g_object_unref0 (publishing_authenticator_factory_instance);
		publishing_authenticator_factory_instance = _tmp1_;
	}
	_tmp2_ = publishing_authenticator_factory_instance;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	result = _tmp3_;
	return result;
}

static GeeList*
publishing_authenticator_factory_real_get_available_authenticators (SpitPublishingAuthenticatorFactory* base)
{
	PublishingAuthenticatorFactory * self;
	GeeArrayList* list = NULL;
	GeeArrayList* _tmp0_;
	GeeList* result;
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory);
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
	list = _tmp0_;
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "flickr");
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "facebook");
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "youtube");
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "tumblr");
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "google-photos");
	result = G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_LIST, GeeList);
	return result;
}

static SpitPublishingAuthenticator*
publishing_authenticator_factory_real_create (SpitPublishingAuthenticatorFactory* base,
                                              const gchar* provider,
                                              SpitPublishingPluginHost* host)
{
	PublishingAuthenticatorFactory * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	SpitPublishingAuthenticator* result;
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory);
	g_return_val_if_fail (provider != NULL, NULL);
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (host, SPIT_PUBLISHING_TYPE_PLUGIN_HOST), NULL);
	_tmp0_ = provider;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("flickr")))) {
		switch (0) {
			default:
			{
				PublishingAuthenticatorShotwellFlickrFlickr* _tmp3_;
				_tmp3_ = publishing_authenticator_shotwell_flickr_flickr_new (host);
				result = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("youtube")))) {
		switch (0) {
			default:
			{
				gchar* _tmp4_;
				gchar** _tmp5_;
				gchar** _tmp6_;
				gint _tmp6__length1;
				PublishingAuthenticatorShotwellGoogleGoogle* _tmp7_;
				SpitPublishingAuthenticator* _tmp8_;
				_tmp4_ = g_strdup ("https://www.googleapis.com/auth/youtube");
				_tmp5_ = g_new0 (gchar*, 1 + 1);
				_tmp5_[0] = _tmp4_;
				_tmp6_ = _tmp5_;
				_tmp6__length1 = 1;
				_tmp7_ = publishing_authenticator_shotwell_google_google_new (_tmp6_, 1, _ ("You are not currently logged into YouTube.\n" \
"\n" \
"You must have already signed up for a Google account and set it up for" \
" use with YouTube to continue. You can set up most accounts by using y" \
"our browser to log into the YouTube site at least once.\n" \
"\n" \
"Shotwell uses the YouTube API services <a href=\"https://developers.go" \
"ogle.com/youtube\">https://developers.google.com/youtube</a> for acces" \
"sing your YouTube channel and upload the videos. By using Shotwell to " \
"access YouTube, you agree to be bound to the YouTube Terms of Service " \
"as available at <a href=\"https://www.youtube.com/t/terms\">https://ww" \
"w.youtube.com/t/terms</a>\n" \
"\n" \
"Shotwell's privacy policy regarding the use of data related to your Go" \
"ogle account in general and YouTube in particular can be found in our " \
"<a href=\"help:shotwell/privacy-policy\">online services privacy polic" \
"y</a>\n" \
"\n" \
"For Google's own privacy policy, please refer to <a href=\"https://pol" \
"icies.google.com/privacy\">https://policies.google.com/privacy</a>"), host);
				_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
				_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
				result = _tmp8_;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("tumblr")))) {
		switch (0) {
			default:
			{
				PublishingAuthenticatorShotwellTumblrTumblr* _tmp9_;
				_tmp9_ = publishing_authenticator_shotwell_tumblr_tumblr_new (host);
				result = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("google-photos")))) {
		switch (0) {
			default:
			{
				gchar* _tmp10_;
				gchar* _tmp11_;
				gchar** _tmp12_;
				gchar** _tmp13_;
				gint _tmp13__length1;
				PublishingAuthenticatorShotwellGoogleGoogle* _tmp14_;
				SpitPublishingAuthenticator* _tmp15_;
				_tmp10_ = g_strdup ("https://www.googleapis.com/auth/photoslibrary.appendonly");
				_tmp11_ = g_strdup ("https://www.googleapis.com/auth/photoslibrary.readonly.appcreateddata");
				_tmp12_ = g_new0 (gchar*, 2 + 1);
				_tmp12_[0] = _tmp10_;
				_tmp12_[1] = _tmp11_;
				_tmp13_ = _tmp12_;
				_tmp13__length1 = 2;
				_tmp14_ = publishing_authenticator_shotwell_google_google_new (_tmp13_, 2, _ ("You are not currently logged into Google Photos.\n" \
"\n" \
"You must have already signed up for a Google account and set it up for" \
" use with Google Photos. Shotwell uses the Google Photos API services " \
"<a href=\"https://developers.google.com/photos/\">https://developers.g" \
"oogle.com/photos/</a> for all interaction with your Google Photos data" \
". You will have to grant access Shotwell to your Google Photos library" \
".\n" \
"\n" \
"Shotwell's privacy policy regarding the use of data related to your Go" \
"ogle account in general and Google Photos in particular can be found i" \
"n our <a href=\"help:shotwell/privacy-policy\">online services privacy" \
" policy</a>. For Google's own privacy policy, please refer to <a href=" \
"\"https://policies.google.com/privacy\">https://policies.google.com/pr" \
"ivacy</a>"), host);
				_tmp15_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
				_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
				result = _tmp15_;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = NULL;
				return result;
			}
		}
	}
}

PublishingAuthenticatorFactory*
publishing_authenticator_factory_construct (GType object_type)
{
	PublishingAuthenticatorFactory * self = NULL;
	self = (PublishingAuthenticatorFactory*) g_object_new (object_type, NULL);
	return self;
}

PublishingAuthenticatorFactory*
publishing_authenticator_factory_new (void)
{
	return publishing_authenticator_factory_construct (PUBLISHING_AUTHENTICATOR_TYPE_FACTORY);
}

static void
publishing_authenticator_factory_class_init (PublishingAuthenticatorFactoryClass * klass,
                                             gpointer klass_data)
{
	publishing_authenticator_factory_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = publishing_authenticator_factory_finalize;
}

static void
publishing_authenticator_factory_spit_publishing_authenticator_factory_interface_init (SpitPublishingAuthenticatorFactoryIface * iface,
                                                                                       gpointer iface_data)
{
	publishing_authenticator_factory_spit_publishing_authenticator_factory_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_available_authenticators = (GeeList* (*) (SpitPublishingAuthenticatorFactory*)) publishing_authenticator_factory_real_get_available_authenticators;
	iface->create = (SpitPublishingAuthenticator* (*) (SpitPublishingAuthenticatorFactory*, const gchar*, SpitPublishingPluginHost*)) publishing_authenticator_factory_real_create;
}

static void
publishing_authenticator_factory_instance_init (PublishingAuthenticatorFactory * self,
                                                gpointer klass)
{
}

static void
publishing_authenticator_factory_finalize (GObject * obj)
{
	PublishingAuthenticatorFactory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory);
	G_OBJECT_CLASS (publishing_authenticator_factory_parent_class)->finalize (obj);
}

static GType
publishing_authenticator_factory_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PublishingAuthenticatorFactoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_authenticator_factory_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingAuthenticatorFactory), 0, (GInstanceInitFunc) publishing_authenticator_factory_instance_init, NULL };
	static const GInterfaceInfo spit_publishing_authenticator_factory_info = { (GInterfaceInitFunc) publishing_authenticator_factory_spit_publishing_authenticator_factory_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType publishing_authenticator_factory_type_id;
	publishing_authenticator_factory_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingAuthenticatorFactory", &g_define_type_info, 0);
	g_type_add_interface_static (publishing_authenticator_factory_type_id, SPIT_PUBLISHING_TYPE_AUTHENTICATOR_FACTORY, &spit_publishing_authenticator_factory_info);
	return publishing_authenticator_factory_type_id;
}

GType
publishing_authenticator_factory_get_type (void)
{
	static volatile gsize publishing_authenticator_factory_type_id__once = 0;
	if (g_once_init_enter (&publishing_authenticator_factory_type_id__once)) {
		GType publishing_authenticator_factory_type_id;
		publishing_authenticator_factory_type_id = publishing_authenticator_factory_get_type_once ();
		g_once_init_leave (&publishing_authenticator_factory_type_id__once, publishing_authenticator_factory_type_id);
	}
	return publishing_authenticator_factory_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

